@@ -98,7 +98,7 @@ class FocalLoss(nn.Module):
         log_p = log_p.contiguous()
 
         # reshape everything
-        log_p = log_p[target[:, 0, ...].unsqueeze(-1).repeat_interleave(input_size[1], dim=-1) >= 0]
+        log_p = log_p[target[:, ...].unsqueeze(-1).repeat_interleave(input_size[1], dim=-1) >= 0]
         log_p = log_p.view(-1, input_size[1])
         p = p.view(-1, input_size[1])
         target = target.view(-1)
